==============
Materia Module
==============

.. image:: https://codecov.io/gh/kijanac/materia/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/kijanac/materia

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github

**Module for integrated materials simulations.**

Longer description coming soon!

---------------
Getting Started
---------------

Prerequisites
-------------

Installing
----------

To install, open a shell terminal and run::

`conda create -n materia -c conda-forge -c kijana materia`

----------
Versioning
----------

-------
Authors
-------

Ki-Jana Carter

-------
License
-------
This project is licensed under the MIT License - see the LICENSE file for details.
